summaryrefslogtreecommitdiffstats
path: root/kfloppy
diff options
context:
space:
mode:
Diffstat (limited to 'kfloppy')
-rw-r--r--kfloppy/floppy.cpp2
-rw-r--r--kfloppy/format.cpp46
-rw-r--r--kfloppy/format.h22
-rw-r--r--kfloppy/zip.cpp18
-rw-r--r--kfloppy/zip.h6
5 files changed, 47 insertions, 47 deletions
diff --git a/kfloppy/floppy.cpp b/kfloppy/floppy.cpp
index 821bc18..8d278ce 100644
--- a/kfloppy/floppy.cpp
+++ b/kfloppy/floppy.cpp
@@ -272,7 +272,7 @@ FloppyData::FloppyData(TQWidget * parent, const char * name)
v3->addStretch( 1 );
//Setup the Help Menu
- helpMenu = new KHelpMenu(this, KGlobal::instance()->aboutData(), false);
+ helpMenu = new KHelpMenu(this, TDEGlobal::instance()->aboutData(), false);
helpbutton = new KPushButton( KStdGuiItem::help(), this );
helpbutton->setAutoRepeat( false );
diff --git a/kfloppy/format.cpp b/kfloppy/format.cpp
index 35ed933..1b26329 100644
--- a/kfloppy/format.cpp
+++ b/kfloppy/format.cpp
@@ -46,7 +46,7 @@ static TQString extPath = TQString();
extPath = path;
}
- return KGlobal::dirs()->findExe(e, extPath);
+ return TDEGlobal::dirs()->findExe(e, extPath);
}
@@ -324,7 +324,7 @@ bool FloppyAction::configureDevice(int drive,int density)
return true;
}
-void FloppyAction::processDone(KProcess *p)
+void FloppyAction::processDone(TDEProcess *p)
{
DEBUGSETUP;
@@ -354,14 +354,14 @@ void FloppyAction::processDone(KProcess *p)
}
}
-void FloppyAction::processStdOut(KProcess *, char *b, int l)
+void FloppyAction::processStdOut(TDEProcess *, char *b, int l)
{
Q_UNUSED(b);
Q_UNUSED(l);
kdDebug(KFAREA) << "stdout:" << TQString::fromLatin1(b,l) << endl;
}
-void FloppyAction::processStdErr(KProcess *p, char *b, int l)
+void FloppyAction::processStdErr(TDEProcess *p, char *b, int l)
{
processStdOut(p,b,l);
}
@@ -370,16 +370,16 @@ bool FloppyAction::startProcess()
{
DEBUGSETUP;
- connect(theProcess,TQT_SIGNAL(processExited(KProcess *)),
- this,TQT_SLOT(processDone(KProcess *)));
- connect(theProcess,TQT_SIGNAL(receivedStdout(KProcess *,char *,int)),
- this,TQT_SLOT(processStdOut(KProcess *,char *,int)));
- connect(theProcess,TQT_SIGNAL(receivedStderr(KProcess *,char *,int)),
- this,TQT_SLOT(processStdErr(KProcess *,char *,int)));
+ connect(theProcess,TQT_SIGNAL(processExited(TDEProcess *)),
+ this,TQT_SLOT(processDone(TDEProcess *)));
+ connect(theProcess,TQT_SIGNAL(receivedStdout(TDEProcess *,char *,int)),
+ this,TQT_SLOT(processStdOut(TDEProcess *,char *,int)));
+ connect(theProcess,TQT_SIGNAL(receivedStderr(TDEProcess *,char *,int)),
+ this,TQT_SLOT(processStdErr(TDEProcess *,char *,int)));
theProcess->setEnvironment( "LC_ALL", "C" ); // We need the untranslated output of the tool
- return theProcess->start(KProcess::NotifyOnExit,
- KProcess::AllOutput);
+ return theProcess->start(TDEProcess::NotifyOnExit,
+ TDEProcess::AllOutput);
}
@@ -425,7 +425,7 @@ bool FDFormat::configure(bool v)
}
if (theProcess) delete theProcess;
- theProcess = new KProcess;
+ theProcess = new TDEProcess;
formatTrackCount=0;
@@ -464,7 +464,7 @@ bool FDFormat::configure(bool v)
// need, since the messages can be standardized across OSsen.
//
//
-void FDFormat::processStdOut(KProcess *, char *b, int l)
+void FDFormat::processStdOut(TDEProcess *, char *b, int l)
{
DEBUGSETUP;
TQString s;
@@ -586,7 +586,7 @@ DDZeroOut::DDZeroOut(TQObject *p) :
}
delete theProcess;
- theProcess = new KProcess;
+ theProcess = new TDEProcess;
*theProcess << m_ddName ;
@@ -601,7 +601,7 @@ DDZeroOut::DDZeroOut(TQObject *p) :
}
-void DDZeroOut::processDone(KProcess *p)
+void DDZeroOut::processDone(TDEProcess *p)
{
kdDebug(KFAREA) << (__PRETTY_FUNCTION__) << endl;
@@ -685,7 +685,7 @@ void FATFilesystem::exec()
}
if (theProcess) delete theProcess;
- KProcess *p = theProcess = new KProcess;
+ TDEProcess *p = theProcess = new TDEProcess;
*p << newfs_fat;
#ifdef ANY_BSD
@@ -715,7 +715,7 @@ void FATFilesystem::exec()
}
}
-void FATFilesystem::processStdOut(KProcess *, char *b, int l)
+void FATFilesystem::processStdOut(TDEProcess *, char *b, int l)
{
#ifdef ANY_BSD
// ### TODO: do some checks
@@ -786,7 +786,7 @@ void UFSFilesystem::exec()
}
if (theProcess) delete theProcess;
- KProcess *p = theProcess = new KProcess;
+ TDEProcess *p = theProcess = new TDEProcess;
*p << newfs;
@@ -865,7 +865,7 @@ void Ext2Filesystem::exec()
}
if (theProcess) delete theProcess;
- KProcess *p = theProcess = new KProcess;
+ TDEProcess *p = theProcess = new TDEProcess;
*p << newfs;
*p << "-q";
@@ -881,7 +881,7 @@ void Ext2Filesystem::exec()
}
}
-void Ext2Filesystem::processStdOut(KProcess *, char *b, int l)
+void Ext2Filesystem::processStdOut(TDEProcess *, char *b, int l)
{
#ifdef ANY_BSD
// ### TODO: do some checks
@@ -959,7 +959,7 @@ void MinixFilesystem::exec()
}
if (theProcess) delete theProcess;
- KProcess *p = theProcess = new KProcess;
+ TDEProcess *p = theProcess = new TDEProcess;
*p << newfs;
@@ -975,7 +975,7 @@ void MinixFilesystem::exec()
}
}
-void MinixFilesystem::processStdOut(KProcess *, char *b, int l)
+void MinixFilesystem::processStdOut(TDEProcess *, char *b, int l)
{
TQString s ( TQString::fromLatin1( b, l ) );
kdDebug(KFAREA) << s << endl;
diff --git a/kfloppy/zip.cpp b/kfloppy/zip.cpp
index 51da7ef..2f2b3be 100644
--- a/kfloppy/zip.cpp
+++ b/kfloppy/zip.cpp
@@ -138,17 +138,17 @@ void ZipFormat::quit()
formatStep=0;
if (p) delete p;
- p = new KProcess();
+ p = new TDEProcess();
if (statusTimer) delete statusTimer;
statusTimer = new TQTimer(this);
- connect(p,TQT_SIGNAL(processExited(KProcess *)),
+ connect(p,TQT_SIGNAL(processExited(TDEProcess *)),
this,TQT_SLOT(transition()));
- connect(p,TQT_SIGNAL(receivedStdout(KProcess *,char *,int)),
- this,TQT_SLOT(processResult(KProcess *,char *,int)));
- connect(p,TQT_SIGNAL(receivedStderr(KProcess *,char *,int)),
- this,TQT_SLOT(processResult(KProcess *,char *,int)));
+ connect(p,TQT_SIGNAL(receivedStdout(TDEProcess *,char *,int)),
+ this,TQT_SLOT(processResult(TDEProcess *,char *,int)));
+ connect(p,TQT_SIGNAL(receivedStderr(TDEProcess *,char *,int)),
+ this,TQT_SLOT(processResult(TDEProcess *,char *,int)));
connect(statusTimer,TQT_SIGNAL(timeout()),
this,TQT_SLOT(statusRequest()));
@@ -189,7 +189,7 @@ void ZipFormat::transition()
<< "of=/dev/afd0c"
<< "bs=8192" ;
*p << TQString("count=%1").arg(totalBlocks);
- if (!p->start(KProcess::NotifyOnExit,KProcess::AllOutput))
+ if (!p->start(TDEProcess::NotifyOnExit,TDEProcess::AllOutput))
{
emit statusMessage(i18n("Cannot start dd to zero disk."));
emit formatDone(-1);
@@ -222,7 +222,7 @@ void ZipFormat::transition()
*p << "-U" ;
}
*p << "/dev/afd0c" ;
- if (!p->start(KProcess::NotifyOnExit,KProcess::AllOutput))
+ if (!p->start(TDEProcess::NotifyOnExit,TDEProcess::AllOutput))
{
emit statusMessage(i18n("Cannot start newfs."));
emit formatDone(-1);
@@ -245,7 +245,7 @@ void ZipFormat::transition()
}
}
-void ZipFormat::processResult(KProcess *, char *b, int l)
+void ZipFormat::processResult(TDEProcess *, char *b, int l)
{
DEBUGSETUP;
diff --git a/kfloppy/zip.h b/kfloppy/zip.h
index 525eb3f..e9a66a3 100644
--- a/kfloppy/zip.h
+++ b/kfloppy/zip.h
@@ -41,7 +41,7 @@
class TQCheckBox;
class TQTimer;
-class KProcess;
+class TDEProcess;
class KConfig;
class ZipFormat : public DiskFormat
@@ -74,7 +74,7 @@ protected:
static TQString newfs,dd;
- KProcess *p; ///< dd or newfs, doing the real work
+ TDEProcess *p; ///< dd or newfs, doing the real work
int formatStep; ///< keeps track of what phase we are in
// Variables for the zeroing phase
@@ -93,7 +93,7 @@ protected slots:
* processResult() reads output
* from either dd or newfs and interprets it.
*/
- void processResult(KProcess *,char *,int);
+ void processResult(TDEProcess *,char *,int);
/**
*statusRequest()
diff --git a/kfloppy/format.h b/kfloppy/format.h
index a33ff53..2da577c 100644
--- a/kfloppy/format.h
+++ b/kfloppy/format.h
@@ -167,7 +167,7 @@ typedef struct { const char **devices;
int tracks;
int flags; } fdinfo;
-class KProcess;
+class TDEProcess;
/**
* Concrete action for running a single external program.
@@ -219,11 +219,11 @@ protected slots:
/**
* \brief Provide handling of the exit of the external program
*/
- virtual void processDone(KProcess *);
+ virtual void processDone(TDEProcess *);
/**
* \brief Provide handling of stdout
*/
- virtual void processStdOut(KProcess *, char *, int);
+ virtual void processStdOut(TDEProcess *, char *, int);
/**
* \brief Provide handling stderr.
*
@@ -231,14 +231,14 @@ protected slots:
* to processStdOut(), so you need reimplement only
* FloppyAction::processStdOut if you choose.
*/
- virtual void processStdErr(KProcess *, char *, int);
+ virtual void processStdErr(TDEProcess *, char *, int);
protected:
- KProcess *theProcess;
+ TDEProcess *theProcess;
TQString theProcessName; ///< human-readable
/**
* Sets up connections, calls KProcess::run().
* You need to *theProcess << program << args ; first.
*/
@@ -273,7 +273,7 @@ public:
bool configure(bool verify);
- virtual void processStdOut(KProcess *, char *,int);
+ virtual void processStdOut(TDEProcess *, char *,int);
protected:
static TQString fdformatName; ///< path to executable.
@@ -306,7 +306,7 @@ protected:
/**
* \brief Provide handling of the exit of the external program
*/
- virtual void processDone(KProcess *);
+ virtual void processDone(TDEProcess *);
protected:
static TQString m_ddName; ///< path to executable.
} ;
@@ -333,7 +333,7 @@ public:
bool configure(bool verify, bool label, const TQString &l);
/// Parse output
- virtual void processStdOut(KProcess*, char* b, int l);
+ virtual void processStdOut(TDEProcess*, char* b, int l);
protected:
static TQString newfs_fat;
@@ -359,7 +359,7 @@ public:
bool configure(bool verify, bool label, const TQString &l);
/// Parse output
- virtual void processStdOut(KProcess*, char* b, int l);
+ virtual void processStdOut(TDEProcess*, char* b, int l);
protected:
static TQString newfs;
@@ -409,7 +409,7 @@ public:
bool configure(bool verify, bool label, const TQString &l);
/// Parse output
- virtual void processStdOut(KProcess*, char* b, int l);
+ virtual void processStdOut(TDEProcess*, char* b, int l);
protected:
static TQString newfs;
@@ -231,14 +231,14 @@ protected slots:
TQString theProcessName; ///< human-readable
/**
- * Sets up connections, calls KProcess::run().
+ * Sets up connections, calls TDEProcess::run().
* You need to *theProcess << program << args ; first.
*/